@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
 our $DATE = '2016-10-07'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -179,10 +179,11 @@ sub _parse_raw_value {
         } elsif ($enc eq 'path' || $enc eq 'paths') {
 
             if ($val =~ m!\A~([^/]+)?(?:/|\z)!) {
-                no warnings 'uninitialized';
-                my @pw = $1 ? getpwnam($1) : getpwuid($>);
-                return ("Unknown user '$1' in path") unless @pw;
-                $val =~ s!\A~([^/]+)?!$pw[7]!;
+                require File::HomeDir;
+                my $home_dir = defined($1) ?
+                    File::HomeDir->users_home($1) : File::HomeDir->my_home;
+                return ("Unknown user '$1' in path") unless $home_dir;
+                $val =~ s!\A~([^/]+)?!$home_dir!;
             }
             $val =~ s!(?<=.)/\z!!;
 
@@ -431,7 +432,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.26 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-10-07.
+This document describes version 0.27 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-10-07.
 
 =head1 EXPRESSION
 
